@@ -2,7 +2,7 @@
 ** DVIReader.cpp                                                        **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2013 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -53,6 +53,8 @@ DVIReader::DVIReader (istream &is, DVIActions *a) : StreamReader(is), _dviFormat
 	_currPageNum = 0;
 	_pageLength = 0;
 	_pagePos = 0;
+	_prevBop = 0;
+	_mag = 1;
 }
 
 
@@ -349,6 +351,8 @@ void DVIReader::cmdPre (int) {
 	verifyDVIFormat(_dviFormat);
 	UInt32 num = readUnsigned(4);  // numerator units of measurement
 	UInt32 den = readUnsigned(4);  // denominator units of measurement
+	if (den == 0)
+		throw DVIException("denominator of measurement unit is zero");
 	_mag = readUnsigned(4);        // magnification
 	UInt32 k   = readUnsigned(1);  // length of following comment
 	string cmt = readString(k);    // comment
@@ -365,6 +369,8 @@ void DVIReader::cmdPost (int) {
 	_prevBop   = readUnsigned(4);  // pointer to previous bop
 	UInt32 num = readUnsigned(4);
 	UInt32 den = readUnsigned(4);
+	if (den == 0)
+		throw DVIException("denominator of measurement unit is zero");
 	_mag = readUnsigned(4);
 	_pageHeight = readUnsigned(4); // height of tallest page in dvi units
 	_pageWidth  = readUnsigned(4); // width of widest page in dvi units
@@ -773,6 +779,9 @@ void DVIReader::cmdXFontDef (int) {
 	if (flags & 0x0100) { // vertical?
 	}
 	if (flags & 0x0200) { // colored?
+		// The font color must not interfere with color specials. If the font color is not black,
+		// all color specials should be ignored, i.e. glyphs of a non-black font have a fixed color
+		// that can't be changed by colors specials.
 		UInt32 rgba = readUnsigned(4);
 		color.set(UInt8(rgba >> 24), UInt8((rgba >> 16) & 0xff), UInt8((rgba >> 8) & 0xff));
 	}
@@ -787,12 +796,8 @@ void DVIReader::cmdXFontDef (int) {
 		for (int i=0; i < num_variations; i++)
 			readUnsigned(4);
 	}
-	if (_inPage && _actions && _actions->fontProcessingEnabled()) {
+	if (_inPage && _actions && _actions->fontProcessingEnabled())
 		FontManager::instance().registerFont(fontnum, fontname, ptsize, style, color);
-//		if (NativeFont *font = dynamic_cast<NativeFont*>(FontManager::instance().getFontById(id))) {
-//			font->setStyle(style);
-//		}
-	}
 }
 
 
