@@ -2,7 +2,7 @@
 ** FileFinder.cpp                                                       **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2013 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -112,7 +112,6 @@ std::string FileFinder::version () {
 	catch (MessageException &e) {
 		if (autoinit)
 			finish();
-		return "not available";
 	}
 #else
 	if (const char *v = strrchr(KPSEVERSION, ' '))
@@ -157,7 +156,12 @@ static const char* find_file (const std::string &fname, const char *ftype) {
 		process.run(&buf);
 		return buf.empty() ? 0 : buf.c_str();
 	}
-	return miktex->findFile(fname.c_str());
+	try {
+		return miktex->findFile(fname.c_str());
+	}
+	catch (const MessageException &e) {
+		return 0;
+	}
 #else
 #ifdef TEXLIVEWIN32
 	if (ext == "exe") {
