@@ -2,7 +2,7 @@
 ** FontMap.cpp                                                          **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2013 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -249,7 +249,7 @@ ostream& FontMap::write (ostream &os) const {
  *  @param[in] path to directory containing the map files to be read */
 void FontMap::readdir (const string &dirname) {
 	Directory dir(dirname);
-	while (const char *fname = dir.read('f')) {
+	while (const char *fname = dir.read(Directory::ET_FILE)) {
 		if (strlen(fname) >= 4 && strcmp(fname+strlen(fname)-4, ".map") == 0) {
 			string path = dirname + "/" + fname;
 			read(path.c_str());
