@@ -2,7 +2,7 @@
 ** SpecialManager.cpp                                                   **
 **                                                                      **
 ** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2013 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -153,6 +153,7 @@ void SpecialManager::notifyPositionChange (double x, double y) const {
 
 
 void SpecialManager::writeHandlerInfo (ostream &os) const {
+	ios::fmtflags osflags(os.flags());
 	typedef map<string, SpecialHandler*> SortMap;
 	SortMap m;
 	FORALL(_handlers, ConstIterator, it)
@@ -164,5 +165,6 @@ void SpecialManager::writeHandlerInfo (ostream &os) const {
 			os << it->second->info();
 		os << endl;
 	}
+	os.flags(osflags);  // restore format flags
 }
 
